[−][src]Trait trie_db::HashDBRef
Trait for immutable reference of HashDB.
Required methods
fn get(
&self,
key: &<H as Hasher>::Out,
prefix: (&[u8], Option<u8>)
) -> Option<T>[−]
&self,
key: &<H as Hasher>::Out,
prefix: (&[u8], Option<u8>)
) -> Option<T>
Look up a given hash into the bytes that hash to it, returning None if the hash is not known.
fn contains(
&self,
key: &<H as Hasher>::Out,
prefix: (&[u8], Option<u8>)
) -> bool[−]
&self,
key: &<H as Hasher>::Out,
prefix: (&[u8], Option<u8>)
) -> bool
Check for the existance of a hash-key.
Implementors
impl<'a, H, T> HashDBRef<H, T> for &'a (dyn HashDB<H, T> + 'a) where
H: Hasher, [src][+]
H: Hasher,
impl<'a, H, T> HashDBRef<H, T> for &'a mut (dyn HashDB<H, T> + 'a) where
H: Hasher, [src][+]
H: Hasher,
impl<H, KF, T> HashDBRef<H, T> for MemoryDB<H, KF, T> where
H: KeyHasher,
T: Default + PartialEq<T> + for<'a> From<&'a [u8]> + Clone + Send + Sync,
KF: Send + Sync + KeyFunction<H>,
impl<H, KF, T> HashDBRef<H, T> for MemoryDB<H, KF, T> where
H: KeyHasher,
T: Default + PartialEq<T> + for<'a> From<&'a [u8]> + Clone + Send + Sync,
KF: Send + Sync + KeyFunction<H>, impl<'a, DB, H, T> HashDBRef<H, T> for KeySpacedDB<'a, DB, H> where
DB: HashDBRef<H, T>,
H: Hasher,
T: From<&'static [u8]>,
impl<'a, DB, H, T> HashDBRef<H, T> for KeySpacedDB<'a, DB, H> where
DB: HashDBRef<H, T>,
H: Hasher,
T: From<&'static [u8]>,